@@ -1,7 +1,10 @@
 #' Determine gamma value by data type.
 #' @inheritParams dtangle
-#' @export
 get_gamma <- function(data_type) {
+    
+    if (is.null(data_type)) 
+        return(1)
+    
     if (data_type == "microarray-probe") {
         gamma <- gma$ma_probe
     } else if (data_type == "microarray-gene") {
